@@ -2,7 +2,7 @@
 
 #' Get a dataframe of scoring history, utilizing the ff_scoring and load_player_stats functions.
 #'
-#' @param conn a conn object created by \code{ff_connect()}
+#' @param conn a conn object created by `ff_connect()`
 #' @param season season a numeric vector of seasons (earliest available year is 1999)
 #' @param ... other arguments
 #'
@@ -30,7 +30,13 @@ ff_scoringhistory.flea_conn <- function(conn, season = 1999:2020, ...) {
   # Use custom ffscrapr function to get positions fron nflfastR rosters
   fastr_rosters <-
     nflfastr_rosters(season) %>%
-    dplyr::mutate(position = dplyr::if_else(.data$position %in% c("HB", "FB"), "RB", .data$position))
+    dplyr::mutate(position = dplyr::if_else(.data$position %in% c("HB", "FB"), "RB", .data$position)) %>%
+    dplyr::left_join(
+      dp_playerids() %>%
+        dplyr::select("fleaflicker_id","sportradar_id") %>%
+        dplyr::filter(!is.na(.data$sportradar_id)),
+      by = c("sportradar_id")
+    )
 
   # Load stats from nflfastr and map the rules from the internal stat_mapping file
   nflfastr_weekly() %>%
@@ -51,12 +57,12 @@ ff_scoringhistory.flea_conn <- function(conn, season = 1999:2020, ...) {
     dplyr::group_by(.data$season, .data$week, .data$player_id, .data$sportradar_id) %>%
     dplyr::mutate(points = round(sum(.data$points, na.rm = TRUE), 2)) %>%
     dplyr::ungroup() %>%
-    dplyr::select("season", "week",
-      "gsis_id" = "player_id", "sportradar_id", "player_name", "pos" = "position",
-      "team" = "recent_team", "metric", "value", "points"
+    dplyr::select(
+      "season", "week", "gsis_id" = "player_id", "sportradar_id", "fleaflicker_id",
+      "player_name", "pos" = "position", "team" = "recent_team", "metric", "value", "points"
     ) %>%
     tidyr::pivot_wider(
-      id_cols = c("season", "week", "gsis_id", "sportradar_id", "player_name", "pos", "team", "points"),
+      id_cols = c("season", "week", "gsis_id", "sportradar_id", "fleaflicker_id", "player_name", "pos", "team", "points"),
       names_from = .data$metric,
       values_from = .data$value,
       values_fill = 0,
